package gov.usgs.earthquake.nshmp.gmm;

import static gov.usgs.earthquake.nshmp.gmm.Gmm.GOMEZ_22_CRUSTAL;
import static gov.usgs.earthquake.nshmp.gmm.Gmm.GOMEZ_22_NONCRUSTAL;
import static gov.usgs.earthquake.nshmp.gmm.Gmm.MA_05;

import java.io.IOException;
import java.util.EnumSet;
import java.util.Set;
import java.util.stream.Stream;

import org.junit.jupiter.api.extension.ExtensionContext;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.Arguments;
import org.junit.jupiter.params.provider.ArgumentsProvider;
import org.junit.jupiter.params.provider.ArgumentsSource;

public class PRVI_2025_GMMS_tests implements ArgumentsProvider {

  private static String GMM_INPUTS = "/gmm/prvi-2025-gmms-inputs.csv";
  private static String GMM_RESULTS = "/gmm/prvi-2025-gmms-results.csv";

  @ParameterizedTest(name = "({index}) {0} {2} {1}")
  @ArgumentsSource(PRVI_2025_GMMS_tests.class)
  void test(int index, Gmm gmm, Imt imt, double exMedian, double exSigma, String inputs) {
    GmmTest.test(index, gmm, imt, exMedian, exSigma, inputs);
  }

  @Override
  public Stream<? extends Arguments> provideArguments(ExtensionContext context) throws Exception {
    return GmmTest.loadResults(GMM_RESULTS, GMM_INPUTS);
  }

  /* Result generation sets */
  private static Set<Gmm> gmms = EnumSet.of(
      MA_05,
      GOMEZ_22_CRUSTAL,
      GOMEZ_22_NONCRUSTAL);

  // private static Set<Imt> imts = MotazedianAtkinson_2005.COEFFS.imts();
  private static Set<Imt> imts = Gomez_2022.COEFFS.imts();

  public static void main(String[] args) throws IOException {
    GmmTest.generateResults(gmms, imts, GMM_INPUTS, GMM_RESULTS);
    System.out.println("Done");
  }
}
